@@ -50,6 +50,8 @@ __all__ = [
     "DevicesResponse",
     "DevicesError",
     "DeviceOneTimeKeyCount",
+    "DiscoveryInfoError",
+    "DiscoveryInfoResponse",
     "DownloadResponse",
     "DownloadError",
     "ErrorResponse",
@@ -143,6 +145,8 @@ __all__ = [
     "ToDeviceError",
     "RoomContextResponse",
     "RoomContextError",
+    "UploadFilterError",
+    "UploadFilterResponse",
     "UpdateReceiptMarkerError",
     "UpdateReceiptMarkerResponse",
 ]
@@ -564,6 +568,41 @@ class PresenceSetError(ErrorResponse):
 class ProfileSetAvatarError(ErrorResponse):
     pass
 
+@dataclass
+class DiscoveryInfoError(ErrorResponse):
+    pass
+
+
+@dataclass
+class DiscoveryInfoResponse(Response):
+    """A response for a successful discovery info request.
+
+    Attributes:
+        homeserver_url (str): The base URL of the homeserver corresponding to
+            the requested domain.
+
+        identity_server_url (str, optional): The base URL of the identity
+            server corresponding to the requested domain, if any.
+    """
+
+    homeserver_url: str = field()
+    identity_server_url: Optional[str] = None
+
+    @classmethod
+    @verify(Schemas.discovery_info, DiscoveryInfoError)
+    def from_dict(
+        cls, parsed_dict: Dict[str, Any],
+    ) -> Union["DiscoveryInfoResponse", DiscoveryInfoError]:
+
+        homeserver_url = parsed_dict["m.homeserver"]["base_url"].rstrip("/")
+
+        identity_server_url = parsed_dict.get(
+            "m.identity_server", {},
+        ).get("base_url", "").rstrip("/") or None
+
+        return cls(homeserver_url, identity_server_url)
+
+
 
 @dataclass
 class RegisterErrorResponse(ErrorResponse):
@@ -1713,3 +1752,26 @@ class SyncResponse(Response):
             to_device,
             presence_events
         )
+
+
+class UploadFilterError(ErrorResponse):
+    pass
+
+
+@dataclass
+class UploadFilterResponse(Response):
+    """Response representing a successful filter upload request.
+
+    Attributes:
+        filter_id (str): A filter ID that may be used in
+            future requests to restrict which events are returned to the
+            client.
+    """
+    filter_id: str = field()
+
+    @classmethod
+    @verify(Schemas.upload_filter, UploadFilterError)
+    def from_dict(
+        cls, parsed_dict: Dict[Any, Any],
+    ) -> Union["UploadFilterResponse", UploadFilterError]:
+        return cls(parsed_dict["filter_id"])
